@@ -141,6 +141,15 @@ class DocumentEvolution(object):
         """
         assert doc.get("format") == "Dashboard Bundle Format 1.1"
         doc["format"] = "Dashboard Bundle Format 1.2"
+    
+    def _evolution_from_1_2_to_1_3(doc):
+        """
+        Evolution method for 1.2 -> 1.3:
+            
+            * No changes required
+        """
+        assert doc.get("format") == "Dashboard Bundle Format 1.2"
+        doc["format"] = "Dashboard Bundle Format 1.3"
 
     EVOLUTION_PATH = [
         ("Dashboard Bundle Format 1.0",
@@ -152,4 +161,7 @@ class DocumentEvolution(object):
         ("Dashboard Bundle Format 1.1",
          "Dashboard Bundle Format 1.2",
          _evolution_from_1_1_to_1_2),
+        ("Dashboard Bundle Format 1.2",
+         "Dashboard Bundle Format 1.3",
+         _evolution_from_1_2_to_1_3),
     ]
